@@ -50,238 +50,224 @@ where
         // position
 
         // We will inline if possible.
-        match &var.name {
-            Pat::Ident(i) => {
-                if i.id.sym == *"arguments" {
+        if let Pat::Ident(i) = &var.name {
+            if i.id.sym == *"arguments" {
+                return;
+            }
+            if self.options.top_retain.contains(&i.id.sym) {
+                return;
+            }
+
+            // Store variables if it's used only once
+            if let Some(usage) = self
+                .data
+                .as_ref()
+                .and_then(|data| data.vars.get(&i.to_id()))
+            {
+                if usage.declared_as_catch_param {
                     return;
                 }
-                if self.options.top_retain.contains(&i.id.sym) {
+                if usage.inline_prevented {
                     return;
                 }
 
-                // Store variables if it's used only once
-                if let Some(usage) = self
-                    .data
-                    .as_ref()
-                    .and_then(|data| data.vars.get(&i.to_id()))
-                {
-                    if usage.declared_as_catch_param {
-                        return;
+                if should_preserve && usage.var_kind != Some(VarDeclKind::Const) {
+                    if cfg!(feature = "debug") {
+                        tracing::trace!(
+                            "inline: [x] Preserving non-const variable `{}` because it's top-level",
+                            dump(&var.name, false)
+                        );
                     }
-                    if usage.inline_prevented {
-                        return;
+                    return;
+                }
+
+                if usage.cond_init || usage.used_above_decl {
+                    if cfg!(feature = "debug") {
+                        tracing::trace!("inline: [x] It's cond init or used before decl",);
                     }
+                    return;
+                }
 
-                    if should_preserve && usage.var_kind != Some(VarDeclKind::Const) {
-                        if cfg!(feature = "debug") {
-                            tracing::trace!(
-                                "inline: [x] Preserving non-const variable `{}` because it's \
-                                 top-level",
-                                dump(&var.name, false)
-                            );
-                        }
-                        return;
-                    }
+                if !usage.is_fn_local {
+                    match &**init {
+                        Expr::Lit(..) => {}
 
-                    if usage.cond_init || usage.used_above_decl {
-                        if cfg!(feature = "debug") {
-                            tracing::trace!("inline: [x] It's cond init or used before decl",);
-                        }
-                        return;
-                    }
+                        Expr::Unary(UnaryExpr {
+                            op: op!("!"), arg, ..
+                        }) if matches!(&**arg, Expr::Lit(..)) => {}
 
-                    if !usage.is_fn_local {
-                        match &**init {
-                            Expr::Lit(..) => {}
-
-                            Expr::Unary(UnaryExpr {
-                                op: op!("!"), arg, ..
-                            }) if match &**arg {
-                                Expr::Lit(..) => true,
-                                _ => false,
-                            } => {}
-
-                            Expr::Fn(FnExpr {
-                                function:
-                                    Function {
-                                        body: Some(body), ..
-                                    },
-                                ..
-                            }) => {
-                                if body.stmts.len() == 1
-                                    && match &body.stmts[0] {
-                                        Stmt::Return(..) => true,
-                                        _ => false,
-                                    }
-                                {
-                                } else {
-                                    if cfg!(feature = "debug") {
-                                        tracing::trace!("inline: [x] It's not fn-local");
-                                    }
-                                    return;
-                                }
-                            }
-                            _ => {
+                        Expr::Fn(FnExpr {
+                            function:
+                                Function {
+                                    body: Some(body), ..
+                                },
+                            ..
+                        }) => {
+                            if body.stmts.len() == 1 && matches!(&body.stmts[0], Stmt::Return(..)) {
+                            } else {
                                 if cfg!(feature = "debug") {
                                     tracing::trace!("inline: [x] It's not fn-local");
                                 }
                                 return;
                             }
                         }
-                    }
-
-                    if !usage.reassigned {
-                        match &**init {
-                            Expr::Fn(..) | Expr::Arrow(..) => {
-                                self.typeofs.insert(i.to_id(), js_word!("function"));
+                        _ => {
+                            if cfg!(feature = "debug") {
+                                tracing::trace!("inline: [x] It's not fn-local");
                             }
-                            Expr::Array(..) | Expr::Object(..) => {
-                                self.typeofs.insert(i.to_id(), js_word!("object"));
-                            }
-                            _ => {}
-                        }
-                    }
-
-                    if !usage.mutated {
-                        self.mode.store(i.to_id(), &*init);
-                    }
-
-                    // No use => dropped
-                    if usage.ref_count == 0 {
-                        if init.may_have_side_effects() {
-                            // TODO: Inline partially
                             return;
                         }
-
-                        // TODO: Remove
-                        return;
-                    }
-
-                    let is_inline_enabled = self.options.reduce_vars
-                        || self.options.collapse_vars
-                        || self.options.inline != 0;
-
-                    // Mutation of properties are ok
-                    if is_inline_enabled
-                        && (!usage.mutated
-                            || (usage.assign_count == 0
-                                && !usage.reassigned
-                                && !usage.has_property_mutation))
-                        && match &**init {
-                            Expr::Lit(lit) => match lit {
-                                Lit::Str(s) => usage.ref_count == 1 || s.value.len() <= 3,
-                                Lit::Bool(_) | Lit::Null(_) | Lit::Num(_) | Lit::BigInt(_) => true,
-                                Lit::Regex(_) => self.options.unsafe_regexp,
-                                _ => false,
-                            },
-                            Expr::This(..) => usage.is_fn_local,
-                            Expr::Arrow(arr) => is_arrow_simple_enough(arr),
-                            _ => false,
-                        }
-                    {
-                        self.mode.store(i.to_id(), &*init);
-
-                        if self.options.inline != 0
-                            && !should_preserve
-                            && match &**init {
-                                Expr::Arrow(..) => self.options.unused,
-                                _ => true,
-                            }
-                        {
-                            self.changed = true;
-
-                            tracing::debug!(
-                                "inline: Decided to inline '{}{:?}' because it's simple",
-                                i.id.sym,
-                                i.id.span.ctxt
-                            );
-
-                            if self.ctx.var_kind == Some(VarDeclKind::Const) {
-                                var.span = var.span.apply_mark(self.marks.non_top_level);
-                            }
-
-                            self.lits.insert(i.to_id(), init.take());
-
-                            var.name.take();
-                        } else {
-                            tracing::debug!(
-                                "inline: Decided to copy '{}{:?}' because it's simple",
-                                i.id.sym,
-                                i.id.span.ctxt
-                            );
-
-                            self.lits.insert(i.to_id(), init.clone());
-                        }
-                        return;
-                    }
-
-                    // Single use => inlined
-                    if is_inline_enabled
-                        && !should_preserve
-                        && !usage.reassigned
-                        && (!usage.mutated || usage.is_mutated_only_by_one_call())
-                        && usage.ref_count == 1
-                    {
-                        match &**init {
-                            Expr::Fn(FnExpr {
-                                function: Function { is_async: true, .. },
-                                ..
-                            })
-                            | Expr::Fn(FnExpr {
-                                function:
-                                    Function {
-                                        is_generator: true, ..
-                                    },
-                                ..
-                            })
-                            | Expr::Arrow(ArrowExpr { is_async: true, .. })
-                            | Expr::Arrow(ArrowExpr {
-                                is_generator: true, ..
-                            }) => return,
-                            _ => {}
-                        }
-                        match &**init {
-                            Expr::Lit(Lit::Regex(..)) => {
-                                if !usage.is_fn_local || usage.used_in_loop {
-                                    return;
-                                }
-                            }
-
-                            Expr::This(..) => {
-                                // Don't inline this if it passes function boundaries.
-                                if !usage.is_fn_local {
-                                    return;
-                                }
-                            }
-
-                            _ => {}
-                        }
-
-                        if usage.used_in_loop {
-                            match &**init {
-                                Expr::Lit(..) | Expr::Fn(..) => {}
-                                _ => {
-                                    return;
-                                }
-                            }
-                        }
-
-                        if init.may_have_side_effects() {
-                            return;
-                        }
-
-                        tracing::debug!(
-                            "inline: Decided to inline var '{}' because it's used only once",
-                            i.id
-                        );
-                        self.changed = true;
-                        self.vars_for_inlining.insert(i.to_id(), init.take());
-                        return;
                     }
                 }
+
+                if !usage.reassigned {
+                    match &**init {
+                        Expr::Fn(..) | Expr::Arrow(..) => {
+                            self.typeofs.insert(i.to_id(), js_word!("function"));
+                        }
+                        Expr::Array(..) | Expr::Object(..) => {
+                            self.typeofs.insert(i.to_id(), js_word!("object"));
+                        }
+                        _ => {}
+                    }
+                }
+
+                if !usage.mutated {
+                    self.mode.store(i.to_id(), &*init);
+                }
+
+                // No use => dropped
+                if usage.ref_count == 0 {
+                    if init.may_have_side_effects() {
+                        // TODO: Inline partially
+                        return;
+                    }
+
+                    // TODO: Remove
+                    return;
+                }
+
+                let is_inline_enabled = self.options.reduce_vars
+                    || self.options.collapse_vars
+                    || self.options.inline != 0;
+
+                // Mutation of properties are ok
+                if is_inline_enabled
+                    && (!usage.mutated
+                        || (usage.assign_count == 0
+                            && !usage.reassigned
+                            && !usage.has_property_mutation))
+                    && match &**init {
+                        Expr::Lit(lit) => match lit {
+                            Lit::Str(s) => usage.ref_count == 1 || s.value.len() <= 3,
+                            Lit::Bool(_) | Lit::Null(_) | Lit::Num(_) | Lit::BigInt(_) => true,
+                            Lit::Regex(_) => self.options.unsafe_regexp,
+                            _ => false,
+                        },
+                        Expr::This(..) => usage.is_fn_local,
+                        Expr::Arrow(arr) => is_arrow_simple_enough(arr),
+                        _ => false,
+                    }
+                {
+                    self.mode.store(i.to_id(), &*init);
+
+                    if self.options.inline != 0
+                        && !should_preserve
+                        && match &**init {
+                            Expr::Arrow(..) => self.options.unused,
+                            _ => true,
+                        }
+                    {
+                        self.changed = true;
+
+                        tracing::debug!(
+                            "inline: Decided to inline '{}{:?}' because it's simple",
+                            i.id.sym,
+                            i.id.span.ctxt
+                        );
+
+                        if self.ctx.var_kind == Some(VarDeclKind::Const) {
+                            var.span = var.span.apply_mark(self.marks.non_top_level);
+                        }
+
+                        self.lits.insert(i.to_id(), init.take());
+
+                        var.name.take();
+                    } else {
+                        tracing::debug!(
+                            "inline: Decided to copy '{}{:?}' because it's simple",
+                            i.id.sym,
+                            i.id.span.ctxt
+                        );
+
+                        self.lits.insert(i.to_id(), init.clone());
+                    }
+                    return;
+                }
+
+                // Single use => inlined
+                if is_inline_enabled
+                    && !should_preserve
+                    && !usage.reassigned
+                    && (!usage.mutated || usage.is_mutated_only_by_one_call())
+                    && usage.ref_count == 1
+                {
+                    match &**init {
+                        Expr::Fn(FnExpr {
+                            function: Function { is_async: true, .. },
+                            ..
+                        })
+                        | Expr::Fn(FnExpr {
+                            function:
+                                Function {
+                                    is_generator: true, ..
+                                },
+                            ..
+                        })
+                        | Expr::Arrow(ArrowExpr { is_async: true, .. })
+                        | Expr::Arrow(ArrowExpr {
+                            is_generator: true, ..
+                        }) => return,
+                        _ => {}
+                    }
+                    match &**init {
+                        Expr::Lit(Lit::Regex(..)) => {
+                            if !usage.is_fn_local || usage.used_in_loop {
+                                return;
+                            }
+                        }
+
+                        Expr::This(..) => {
+                            // Don't inline this if it passes function boundaries.
+                            if !usage.is_fn_local {
+                                return;
+                            }
+                        }
+
+                        _ => {}
+                    }
+
+                    if usage.used_in_loop {
+                        match &**init {
+                            Expr::Lit(..) | Expr::Fn(..) => {}
+                            _ => {
+                                return;
+                            }
+                        }
+                    }
+
+                    if init.may_have_side_effects() {
+                        return;
+                    }
+
+                    tracing::debug!(
+                        "inline: Decided to inline var '{}' because it's used only once",
+                        i.id
+                    );
+                    self.changed = true;
+                    self.vars_for_inlining.insert(i.to_id(), init.take());
+                }
             }
-            // TODO
-            _ => {}
         }
     }
 
@@ -289,15 +275,17 @@ where
     fn is_fn_body_simple_enough_to_inline(&self, body: &BlockStmt) -> bool {
         if body.stmts.len() == 1 {
             match &body.stmts[0] {
-                Stmt::Expr(ExprStmt { expr, .. }) => match &**expr {
-                    Expr::Lit(..) => return true,
-                    _ => {}
-                },
+                Stmt::Expr(ExprStmt { expr, .. }) => {
+                    if let Expr::Lit(..) = &**expr {
+                        return true;
+                    }
+                }
 
-                Stmt::Return(ReturnStmt { arg, .. }) => match arg.as_deref() {
-                    Some(Expr::Lit(Lit::Num(..))) => return true,
-                    _ => {}
-                },
+                Stmt::Return(ReturnStmt { arg, .. }) => {
+                    if let Some(Expr::Lit(Lit::Num(..))) = arg.as_deref() {
+                        return true;
+                    }
+                }
 
                 Stmt::Try(TryStmt { block, .. }) => {
                     return self.is_fn_body_simple_enough_to_inline(block)
@@ -486,13 +474,10 @@ where
                     _ => false,
                 })
             {
-                match decl {
-                    Decl::Class(ClassDecl { class, .. }) => {
-                        if class_has_side_effect(&class) {
-                            return;
-                        }
+                if let Decl::Class(ClassDecl { class, .. }) = decl {
+                    if class_has_side_effect(class) {
+                        return;
                     }
-                    _ => {}
                 }
 
                 self.changed = true;
@@ -532,8 +517,6 @@ where
                 } else {
                     self.vars_for_inlining.insert(i.to_id(), e);
                 }
-
-                return;
             } else {
                 if cfg!(feature = "debug") {
                     tracing::trace!("inline: [x] Usage: {:?}", usage);
@@ -544,76 +527,70 @@ where
 
     /// Actually inlines variables.
     pub(super) fn inline(&mut self, e: &mut Expr) {
-        match e {
-            Expr::Ident(i) => {
-                //
-                if let Some(value) = self
-                    .lits
-                    .get(&i.to_id())
-                    .and_then(|v| {
-                        // Prevent infinite recursion.
-                        let ids = idents_used_by(&**v);
-                        if ids.contains(&i.to_id()) {
-                            None
-                        } else {
-                            Some(v)
-                        }
-                    })
-                    .cloned()
-                {
-                    match &*value {
-                        Expr::Lit(Lit::Num(..)) => {
-                            if self.ctx.is_lhs_of_assign {
-                                return;
-                            }
-                        }
-                        Expr::Member(..) => {
-                            if self.ctx.executed_multiple_time {
-                                return;
-                            }
-                        }
-                        _ => {}
+        if let Expr::Ident(i) = e {
+            //
+            if let Some(value) = self
+                .lits
+                .get(&i.to_id())
+                .and_then(|v| {
+                    // Prevent infinite recursion.
+                    let ids = idents_used_by(&**v);
+                    if ids.contains(&i.to_id()) {
+                        None
+                    } else {
+                        Some(v)
                     }
+                })
+                .cloned()
+            {
+                match &*value {
+                    Expr::Lit(Lit::Num(..)) => {
+                        if self.ctx.is_lhs_of_assign {
+                            return;
+                        }
+                    }
+                    Expr::Member(..) => {
+                        if self.ctx.executed_multiple_time {
+                            return;
+                        }
+                    }
+                    _ => {}
+                }
 
-                    self.changed = true;
-                    tracing::debug!("inline: Replacing a variable with cheap expression");
+                self.changed = true;
+                tracing::debug!("inline: Replacing a variable with cheap expression");
 
-                    *e = *value;
+                *e = *value;
+                return;
+            }
+
+            // Check without cloning
+            if let Some(value) = self.vars_for_inlining.get(&i.to_id()) {
+                if self.ctx.is_exact_lhs_of_assign && !is_valid_for_lhs(value) {
                     return;
                 }
 
-                // Check without cloning
-                if let Some(value) = self.vars_for_inlining.get(&i.to_id()) {
-                    if self.ctx.is_exact_lhs_of_assign && !is_valid_for_lhs(&value) {
+                if let Expr::Member(..) = &**value {
+                    if self.ctx.executed_multiple_time {
                         return;
                     }
-
-                    match &**value {
-                        Expr::Member(..) => {
-                            if self.ctx.executed_multiple_time {
-                                return;
-                            }
-                        }
-                        _ => {}
-                    }
-                }
-
-                if let Some(value) = self.vars_for_inlining.get(&i.to_id()) {
-                    self.changed = true;
-                    tracing::debug!(
-                        "inline: Replacing '{}{:?}' with an expression",
-                        i.sym,
-                        i.span.ctxt
-                    );
-
-                    *e = *value.clone();
-
-                    if cfg!(feature = "debug") {
-                        tracing::trace!("inline: [Change] {}", dump(&*e, false))
-                    }
                 }
             }
-            _ => {}
+
+            if let Some(value) = self.vars_for_inlining.get(&i.to_id()) {
+                self.changed = true;
+                tracing::debug!(
+                    "inline: Replacing '{}{:?}' with an expression",
+                    i.sym,
+                    i.span.ctxt
+                );
+
+                *e = *value.clone();
+
+                if cfg!(feature = "debug") {
+                    tracing::trace!("inline: [Change] {}", dump(&*e, false))
+                }
+            }
         }
     }
 }
@@ -638,9 +615,8 @@ fn is_arrow_simple_enough(e: &ArrowExpr) -> bool {
 
         false
     }
-    match &e.body {
-        BlockStmtOrExpr::Expr(e) => return is_arrow_body_simple_enough(&e),
-        _ => {}
+    if let BlockStmtOrExpr::Expr(e) = &e.body {
+        return is_arrow_body_simple_enough(e);
     }
 
     false
