@@ -123,7 +123,7 @@ impl<M> Pure<'_, M> {
         match if_stmt {
             Stmt::If(mut s) => {
                 assert_eq!(s.alt, None);
-                self.changed |= negate(&mut s.test, false, false);
+                negate(&mut s.test, false, false);
 
                 s.cons = if cons.len() == 1 && is_fine_for_if_cons(&cons[0]) {
                     Box::new(cons.into_iter().next().unwrap())
